pyparsing: A Python parsing module
==================================

Description
-----------

A Python Parsing Module

License
-------

MIT License


Upstream Contact
----------------

- Author: Paul McGuire
- Home page: http://pyparsing.wikispaces.com

Dependencies
------------

Python
